.. image:: https://readthedocs.org/projects/better-json-tools/badge/?version=latest
    :target: https://better-json-tools.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

Better JSON Tools
=================

Python module that adds tools to make working with JSON data easier.

Documentation
-------------

If you're looking for documentation please visit:

https://better-json-tools.readthedocs.io/en/stable/


Installation
------------

.. code-block:: bash

   pip install better-json-tools


Features
========

- **Compact encoder** - better JSON formatting.
- **JSONC Decoder** - reading JSONC files.
- **JSON Walkers** - better navigation through JSON objects.
